johnny - generic dep(p)endencies tracker
========================================

Alerting stale dependencies tool and language independent and without central
service.

Running
-------

```bash
pip install .
johnny examples/deps.toml
```
